export type Fetch = (typeof globalThis)["fetch"];
/**
 * `useNetlifyExtensionUIFetch` returns a `fetch`-compatible function that automatically attaches
 * authentication data to requests. Use it to perform requests to [endpoints](/sdk/endpoints/overview/).
 *
 * @returns A fetch function.
 * @example
 * ```tsx
 * import { useNetlifyExtensionUIFetch } from "@netlify/sdk/react";
 * import { useEffect, useState } from "react";
 *
 * const MyComponent = () => {
 *   const fetch = useNetlifyExtensionUIFetch();
 *   const [data, setData] = useState(null);
 *
 *   useEffect(() => {
 *     (async () => {
 *       const res = await fetch("/.netlify/functions/my-endpoint");
 *       if (res.ok) {
 *         setData(await res.json());
 *       }
 *     })();
 *   }, [fetch, setData]);
 *
 *   if (data === null) {
 *     return <div>No data found.</div>;
 *   }
 * };
 * ```
 */
export declare const useNetlifyExtensionUIFetch: () => Fetch;
//# sourceMappingURL=use_netlify_extension_ui_fetch.d.ts.map